@@ -4,7 +4,7 @@ import logging.handlers
 import signal
 import sys
 # from os.path import join
-from taskmanager import TaskManager
+from .taskmanager import TaskManager
 
 
 def run_agent(debug=False, verbose=True):
